==> 18.0.0.tar: www/cgi-bin/modules/verizon_status.php <==
<?php
# We're only going to ever have one modem on here...
#exec("mmcli -L | grep LE910-SVG | cut -d \" \" -f 1 | cut -d \"/\" -f 6 ", $modemNumber);

# hardcoding the first modem
$modemNumber[0]=0;

$verizonroaming = shell_exec("mmcli -m " . $modemNumber[0] . " | grep -i registration | cut -d \" \" -f 22 | sed s/\'//g | tr -d '\n'");
$verizonroaming = str_replace(' ', '', $verizonroaming);
// signal percent
$verizonrssi = shell_exec("mmcli -m " . $modemNumber[0] . " | grep signal | sed 's/[^0-9]*//g' ");
// access tech:
$verizonService = shell_exec("mmcli -m " . $modemNumber[0] . " | grep -i 'access tech' | cut -d : -f 2 | sed s/\'//g ");

$verizonService = strtoupper($verizonService);

// att may be used in the future 10/18/2017 -RR
//$attOutput = file('/tmp/attmetrics');
//$attrssi = explode("\n", $attOutput[0]);
//$attroaming = explode("\n", $attOutput[1]);

// print "<li>";
// if ($attrssi[0] >= -76 && $attrssi[0] < 0) { print "<img id=\"attbars\" src=\"/assets/images/Grey-Bar-5.png\" />"; }
// else if ($attrssi[0] >= -82 && $attrssi[0] < 0) { print "<img id=\"attbars\" src=\"/assets/images/Grey-Bar-4.png\" />"; }
// else if ($attrssi[0] >= -94 && $attrssi[0] < 0) { print "<img id=\"attbars\" src=\"/assets/images/Grey-Bar-3.png\" />"; }
// else if ($attrssi[0] >= -105 && $attrssi[0] < 0) { print "<img id=\"attbars\" src=\"/assets/images/Grey-Bar-2.png\" />"; }
// else if ($attrssi[0] >= -111 && $attrssi[0] < 0) { print "<img id=\"attbars\" src=\"/assets/images/Grey-Bar-1.png\" />"; }
// else { print "<img id=\"attbars\" src=\"/assets/images/Grey-Bar-0.png\" />"; }
// print "AT&T RSSI: <span id=\"attrssi\" class=\"violet\">".$attrssi[0]."</span> - ";
// if ($attroaming[0] == 0) { print "<span id=\"attroaming\">Not roaming</span></li>"; } else if ($attroaming[0] == 1) { print "<span id=\"attroaming\">Roaming</span>$

//print "<li>";
//if ($verizonrssi >=  80) { print "<img id=\"verizonbars\" src=\"/assets/images/Grey-Bar-5.png\" />"; }
//else if ($verizonrssi >=  65) { print "<img id=\"verizonbars\" src=\"/assets/images/Grey-Bar-4.png\" />"; }
//else if ($verizonrssi >= 48) { print "<img id=\"verizonbars\" src=\"/assets/images/Grey-Bar-3.png\" />"; }
//else if ($verizonrssi >= 32) { print "<img id=\"verizonbars\" src=\"/assets/images/Grey-Bar-2.png\" />"; }
//else if ($verizonrssi > 0) { print "<img id=\"verizonbars\" src=\"/assets/images/Grey-Bar-1.png\" />"; }
//else { print "<img id=\"verizonbars\" src=\"/assets/images/Grey-Bar-0.png\" />"; }
//getElementById('verizonrssi') = $verizonrssi;
//getElementById('verizonroaming') = $verizonroaming;

if (strcmp($verizonroaming, "home") == 0) { $verizonroaming = " Not roaming"; }
else if ($verizonroaming == "roaming") { $verizonroaming = " Roaming"; }
else { $verizonroaming = " Unknown roaming"; }

?>

==> 18.0.1.tar: www/cgi-bin/modules/verizon_status.php <==
<?php
# We're only going to ever have one modem on here...
#exec("mmcli -L | grep LE910-SVG | cut -d \" \" -f 1 | cut -d \"/\" -f 6 ", $modemNumber);

# hardcoding the first modem
#$modemNumber[0]=0;

#$verizonroaming = shell_exec("mmcli -m " . $modemNumber[0] . " | grep -i registration | cut -d \" \" -f 22 | sed s/\'//g | tr -d '\n'");
#$verizonroaming = str_replace(' ', '', $verizonroaming);

# FIX !!! find a way to query the GL7500
$verizonroaming = "Not Roaming";

// signal percent using /dev/ttyACM2
$verizonrssi = shell_exec("/usr/bin/verizonSignal ");

// access tech:
#$verizonService = shell_exec("mmcli -m " . $modemNumber[0] . " | grep -i 'access tech' | cut -d : -f 2 | sed s/\'//g ");
#$verizonService = strtoupper($verizonService);



// att may be used in the future 10/18/2017 -RR
//$attOutput = file('/tmp/attmetrics');
//$attrssi = explode("\n", $attOutput[0]);
//$attroaming = explode("\n", $attOutput[1]);

// print "<li>";
// if ($attrssi[0] >= -76 && $attrssi[0] < 0) { print "<img id=\"attbars\" src=\"/assets/images/Grey-Bar-5.png\" />"; }
// else if ($attrssi[0] >= -82 && $attrssi[0] < 0) { print "<img id=\"attbars\" src=\"/assets/images/Grey-Bar-4.png\" />"; }
// else if ($attrssi[0] >= -94 && $attrssi[0] < 0) { print "<img id=\"attbars\" src=\"/assets/images/Grey-Bar-3.png\" />"; }
// else if ($attrssi[0] >= -105 && $attrssi[0] < 0) { print "<img id=\"attbars\" src=\"/assets/images/Grey-Bar-2.png\" />"; }
// else if ($attrssi[0] >= -111 && $attrssi[0] < 0) { print "<img id=\"attbars\" src=\"/assets/images/Grey-Bar-1.png\" />"; }
// else { print "<img id=\"attbars\" src=\"/assets/images/Grey-Bar-0.png\" />"; }
// print "AT&T RSSI: <span id=\"attrssi\" class=\"violet\">".$attrssi[0]."</span> - ";
// if ($attroaming[0] == 0) { print "<span id=\"attroaming\">Not roaming</span></li>"; } else if ($attroaming[0] == 1) { print "<span id=\"attroaming\">Roaming</span>$

//print "<li>";
//if ($verizonrssi >=  80) { print "<img id=\"verizonbars\" src=\"/assets/images/Grey-Bar-5.png\" />"; }
//else if ($verizonrssi >=  65) { print "<img id=\"verizonbars\" src=\"/assets/images/Grey-Bar-4.png\" />"; }
//else if ($verizonrssi >= 48) { print "<img id=\"verizonbars\" src=\"/assets/images/Grey-Bar-3.png\" />"; }
//else if ($verizonrssi >= 32) { print "<img id=\"verizonbars\" src=\"/assets/images/Grey-Bar-2.png\" />"; }
//else if ($verizonrssi > 0) { print "<img id=\"verizonbars\" src=\"/assets/images/Grey-Bar-1.png\" />"; }
//else { print "<img id=\"verizonbars\" src=\"/assets/images/Grey-Bar-0.png\" />"; }
//getElementById('verizonrssi') = $verizonrssi;
//getElementById('verizonroaming') = $verizonroaming;

if (strcmp($verizonroaming, "home") == 0) { $verizonroaming = " Not roaming"; }
else if ($verizonroaming == "roaming") { $verizonroaming = " Roaming"; }
else { $verizonroaming = " Unknown roaming"; }

?>
